# Weby Pilot

Automation for randomly selected websites 🤖.

## Supported Websites

* [BPI](https://www.bancobpi.pt/)
* [BIG](https://big.pt/)

## License

Weby Pilot is currently licensed under the [Apache License, Version 2.0](http://www.apache.org/licenses/).

## Build Automation

[![Build Status](https://github.com/hivesolutions/weby-pilot/workflows/Main%20Workflow/badge.svg)](https://github.com/hivesolutions/weby-pilot/actions)
[![PyPi Status](https://img.shields.io/pypi/v/weby-pilot.svg)](https://pypi.python.org/pypi/weby-pilot)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://www.apache.org/licenses/)
